========
Sketcher
========

Sketcher commands are used to define the entities, such as the geometry, constraints, and dimensions, to create a sketch and to store the values and attributes associated with a particular sketch.


Create constrained sketches
---------------------------

.. autoclass:: abaqus.Sketcher.SketchModel.SketchModel
    :members:
    :special-members: __init__

    .. autoclasstoc::


Classes
-------

ConstrainedSketch
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketch.ConstrainedSketch
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchConstraintModel
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraintModel.ConstrainedSketchConstraintModel
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchDimensionModel
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.ConstrainedSketchDimensionModel.ConstrainedSketchDimensionModel
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchGeometryModel
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometryModel.ConstrainedSketchGeometryModel
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchParameterModel
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchParameter.ConstrainedSketchParameterModel.ConstrainedSketchParameterModel
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchVertexModel
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertexModel.ConstrainedSketchVertexModel
    :members:
    :special-members: __init__

    .. autoclasstoc::


CoincidentConstraint
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.CoincidentConstraint.CoincidentConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConcentricConstraint
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConcentricConstraint.ConcentricConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchConstraint
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ConstrainedSketchConstraint.ConstrainedSketchConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

EqualDistanceConstraint
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualDistanceConstraint.EqualDistanceConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

EqualLengthConstraint
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualLengthConstraint.EqualLengthConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

EqualRadiusConstraint
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.EqualRadiusConstraint.EqualRadiusConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

FixedConstraint
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.FixedConstraint.FixedConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

HorizontalConstraint
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.HorizontalConstraint.HorizontalConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

ParallelConstraint
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.ParallelConstraint.ParallelConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

PerpendicularConstraint
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.PerpendicularConstraint.PerpendicularConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

TangentConstraint
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.TangentConstraint.TangentConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::

VerticalConstraint
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchConstraint.VerticalConstraint.VerticalConstraint
    :members:
    :special-members: __init__

    .. autoclasstoc::


AngularDimension
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.AngularDimension.AngularDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

DistanceDimension
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.DistanceDimension.DistanceDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

HorizontalDimension
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.HorizontalDimension.HorizontalDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

ObliqueDimension
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.ObliqueDimension.ObliqueDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

RadialDimension
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.RadialDimension.RadialDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

VerticalDimension
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchDimension.VerticalDimension.VerticalDimension
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchGeometry
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometry.ConstrainedSketchGeometry
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchGeometryArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstrainedSketchGeometryArray.ConstrainedSketchGeometryArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

Arc3Points
~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Arc3Points.Arc3Points
    :members:
    :special-members: __init__

    .. autoclasstoc::

ArcByCenterEnds
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ArcByCenterEnds.ArcByCenterEnds
    :members:
    :special-members: __init__

    .. autoclasstoc::

ArcByStartEndTangent
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ArcByStartEndTangent.ArcByStartEndTangent
    :members:
    :special-members: __init__

    .. autoclasstoc::

CircleByCenterPerimeter
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.CircleByCenterPerimeter.CircleByCenterPerimeter
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstructionCircleByCenterPerimeter
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstructionCircleByCenterPerimeter.ConstructionCircleByCenterPerimeter
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstructionLine
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.ConstructionLine.ConstructionLine
    :members:
    :special-members: __init__

    .. autoclasstoc::

EllipseByCenterPerimeter
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.EllipseByCenterPerimeter.EllipseByCenterPerimeter
    :members:
    :special-members: __init__

    .. autoclasstoc::

FilletByRadius
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.FilletByRadius.FilletByRadius
    :members:
    :special-members: __init__

    .. autoclasstoc::

getPointAtDistance
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.getPointAtDistance.getPointAtDistance
    :members:
    :special-members: __init__

    .. autoclasstoc::

Line
~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Line.Line
    :members:
    :special-members: __init__

    .. autoclasstoc::

Spline
~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Spline.Spline
    :members:
    :special-members: __init__

    .. autoclasstoc::

Spot
~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchGeometry.Spot.Spot
    :members:
    :special-members: __init__

    .. autoclasstoc::


ConstrainedSketcherOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketcherOptions.ConstrainedSketcherOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchImageOptions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchImageOptions.ConstrainedSketchImageOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchOptions
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchOptions.ConstrainedSketchOptions.ConstrainedSketchOptions
    :members:
    :special-members: __init__

    .. autoclasstoc::

Parameter
~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchParameter.Parameter.Parameter
    :members:
    :special-members: __init__

    .. autoclasstoc::


ConstrainedSketchVertex
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertex.ConstrainedSketchVertex
    :members:
    :special-members: __init__

    .. autoclasstoc::

ConstrainedSketchVertexArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.ConstrainedSketchVertexArray.ConstrainedSketchVertexArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

Spot
~~~~

.. autoclass:: abaqus.Sketcher.ConstrainedSketchVertex.Spot.Spot
    :members:
    :special-members: __init__

    .. autoclasstoc::

.. This is a comment ro supress the warning "(ERROR/3) Document may not end with a transition."
